@@ -1,7 +1,7 @@
 package Web::PerlDistSite::MenuItem;
 use utf8;
 
-our $VERSION = '0.001010';
+our $VERSION = '0.001011';
 
 use Moo;
 use Web::PerlDistSite::Common -lexical, -all;
@@ -65,6 +65,19 @@ has children => (
 	default  => sub { [] },
 );
 
+has meta => (
+	init_arg => undef,
+	is       => 'lazy',
+	isa      => ArrayRef->of( HashRef ),
+	builder  => true,
+);
+
+has _meta_merge => (
+	init_arg => 'meta',
+	is       => 'ro',
+	isa      => ArrayRef->of( HashRef ),
+);
+
 sub from_hashref ( $class, $hashref ) {
 	
 	if ( exists $hashref->{divider} ) {
@@ -223,4 +236,16 @@ sub page_title ( $self ) {
 	return sprintf( '%s — %s', $self->project->name, $self->title );
 }
 
+sub _build_meta ( $self ) {
+	my @meta = @{ $self->_meta_merge // [] };
+	if ( my $title = $self->title ) {
+		push @meta, {
+			name     => 'title',
+			property => 'rdfs:label dc:title og:title',
+			content  => $title,
+		};
+	}
+	return \@meta;
+}
+
 1;
